/* SPDX-License-Identifier: GPL-2.0-only */
#ifndef CPU_INTEL_CPU_IDS_H
#define CPU_INTEL_CPU_IDS_H

/* Supported CPUIDs for different Intel CPU */

#define CPUID_DENVERTON_A0_A1		0x506f0
#define CPUID_DENVERTON_B0		0x506f1
#define CPUID_COOPERLAKE_SP_A0		0x5065a
#define CPUID_COOPERLAKE_SP_A1		0x5065b
#define CPUID_SKYLAKE_SP_A0_A1		0x506f0
#define CPUID_SKYLAKE_SP_B0		0x506f1
#define CPUID_SKYLAKE_SP_4		0x50654
#define CPUID_SKYLAKE_C0		0x406e2
#define CPUID_SKYLAKE_D0		0x406e3
#define CPUID_SKYLAKE_HQ0		0x506e1
#define CPUID_SKYLAKE_HR0		0x506e3
#define CPUID_KABYLAKE_G0		0x406e8
#define CPUID_KABYLAKE_H0		0x806e9
#define CPUID_KABYLAKE_Y0		0x806ea
#define CPUID_KABYLAKE_HA0		0x506e8
#define CPUID_KABYLAKE_HB0		0x906e9
#define CPUID_CANNONLAKE_A0		0x60660
#define CPUID_CANNONLAKE_B0		0x60661
#define CPUID_CANNONLAKE_C0		0x60662
#define CPUID_CANNONLAKE_D0		0x60663
#define CPUID_APOLLOLAKE_A0		0x506c8
#define CPUID_APOLLOLAKE_B0		0x506c9
#define CPUID_APOLLOLAKE_E0		0x506ca
#define CPUID_GLK_A0			0x706a0
#define CPUID_GLK_B0			0x706a1
#define CPUID_GLK_R0			0x706a8
#define CPUID_WHISKEYLAKE_V0		0x806ec
#define CPUID_WHISKEYLAKE_W0		0x806eb
#define CPUID_COFFEELAKE_U0		0x906ea
#define CPUID_COFFEELAKE_B0		0x906eb
#define CPUID_COFFEELAKE_P0		0x906ec
#define CPUID_COFFEELAKE_R0		0x906ed
#define CPUID_JASPERLAKE_A0		0x906c0
#define CPUID_COMETLAKE_U_A0		0xa0660
#define CPUID_COMETLAKE_U_K0_S0		0xa0661
#define CPUID_COMETLAKE_H_S_6_2_G0	0xa0650
#define CPUID_COMETLAKE_H_S_6_2_G1	0xa0653
#define CPUID_COMETLAKE_H_S_10_2_P0	0xa0651
#define CPUID_COMETLAKE_H_S_10_2_P1	0xa0654
#define CPUID_COMETLAKE_H_S_10_2_Q0	0xa0655
#define CPUID_TIGERLAKE_A0		0x806c0
#define CPUID_TIGERLAKE_B0		0x806c1
#define CPUID_TIGERLAKE_P0		0x806d0
#define CPUID_TIGERLAKE_R0		0x806d1
#define CPUID_SAPPHIRERAPIDS_SP_A	0x806f0
#define CPUID_SAPPHIRERAPIDS_SP_B	0x806f1
#define CPUID_SAPPHIRERAPIDS_SP_C	0x806f2
#define CPUID_SAPPHIRERAPIDS_SP_D	0x806f3
#define CPUID_SAPPHIRERAPIDS_SP_E0	0x806f4
#define CPUID_SAPPHIRERAPIDS_SP_E2	0x806f5
#define CPUID_SAPPHIRERAPIDS_SP_E3	0x806f6
#define CPUID_SAPPHIRERAPIDS_SP_E4	0x806f7
#define CPUID_SAPPHIRERAPIDS_SP_Ex	0x806f8
#define CPUID_GRANITERAPIDS		0xA06D0
#define CPUID_SIERRAFOREST		0xA06F0
#define CPUID_ELKHARTLAKE_A0		0x90660
#define CPUID_ELKHARTLAKE_B0		0x90661
#define CPUID_ALDERLAKE_A0		0x90670
#define CPUID_ALDERLAKE_B0		0x90671
#define CPUID_ALDERLAKE_C0		0x90672
#define CPUID_ALDERLAKE_G0		0x90674
#define CPUID_ALDERLAKE_H0		0x90675
#define CPUID_ALDERLAKE_J0		0x906a0
#define CPUID_ALDERLAKE_Q0		0x906a1
#define CPUID_ALDERLAKE_K0		0x906a2
#define CPUID_ALDERLAKE_L0		0x906a3
#define CPUID_ALDERLAKE_R0		0x906a4
#define CPUID_ALDERLAKE_N_A0		0xb06e0
#define CPUID_METEORLAKE_A0_1		0xa06a0
#define CPUID_METEORLAKE_A0_2		0xa06a1
#define CPUID_METEORLAKE_B0		0xa06a2
#define CPUID_METEORLAKE_C0		0xa06a4
#define CPUID_RAPTORLAKE_A0		0xb0670
#define CPUID_RAPTORLAKE_B0		0xb0671
#define CPUID_RAPTORLAKE_C0		0xb06f2
#define CPUID_RAPTORLAKE_H0		0xb06f5
#define CPUID_RAPTORLAKE_J0		0xb06a2
#define CPUID_RAPTORLAKE_Q0		0xb06a3
#define CPUID_LUNARLAKE_A0_1		0xb06d0
#define CPUID_LUNARLAKE_A0_2		0xb06d1
#define CPUID_PANTHERLAKE_A0		0xc06c0
#define CPUID_SNOWRIDGE_A0		0x80660
#define CPUID_SNOWRIDGE_A1		0x80661
#define CPUID_SNOWRIDGE_A2		0x80662
#define CPUID_SNOWRIDGE_A3		0x80663
#define CPUID_SNOWRIDGE_B0		0x80664
#define CPUID_SNOWRIDGE_B1		0x80665
#define CPUID_SNOWRIDGE_C0		0x80667

#endif /* CPU_INTEL_CPU_IDS_H */
